Tie-LevelDB - A Perl Interface to the LevelDB database
======================================================
This module is based on LevelDB NoSQL database from Google.
http://code.google.com/p/leveldb/
INSTALLATION
To install this module type the following:
perl Makefile.PL
make
make test
make install
DEPENDENCIES
Module has no dependencies. LevelDB sources are bundled with this package.
COPYRIGHT AND LICENCE
Copyright (C) 2011 by Sokordia, s.r.o. http://www.sokordia.cz
This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.10.1 or,
at your option, any later version of Perl 5 you may have available.